/// <reference types="node" />
import * as SQS from 'aws-sdk/clients/sqs';
import * as S3 from 'aws-sdk/clients/s3';
import { AWSError } from 'aws-sdk/lib/error';
import { BodyFormat, Squiss } from '.';
import { IMessageAttributes } from './attributeUtils';
import { EventEmitter } from 'events';
import { IS3Upload } from './s3Utils';
import { BatchResultErrorEntry } from 'aws-sdk/clients/sqs';
import { StrictEventEmitter } from './EventEmitterTypesHelper';
export interface IMessageOpts {
    msg: SQS.Message;
    unwrapSns?: boolean;
    bodyFormat?: BodyFormat;
    squiss: Squiss;
    s3Retriever: () => S3;
    s3Retain: boolean;
}
interface IMessageEvents {
    delQueued: void;
    handled: void;
    released: void;
    timeoutReached: void;
    extendingTimeout: void;
    timeoutExtended: void;
    keep: void;
    delError: BatchResultErrorEntry;
    deleted: string;
    autoExtendFail: AWSError;
    autoExtendError: AWSError;
    s3Download: IS3Upload;
    s3Delete: IS3Upload;
}
declare type MessageEmitter = StrictEventEmitter<EventEmitter, IMessageEvents>;
declare const Message_base: new () => MessageEmitter;
export declare class Message extends Message_base {
    private static formatMessage;
    raw: SQS.Message;
    body?: string | any;
    subject?: string;
    topicArn?: string;
    topicName?: string;
    attributes: IMessageAttributes;
    sqsAttributes: {
        [k: string]: string;
    };
    private _squiss;
    private _handled;
    private _opts;
    private _deleteCallback?;
    private _s3Retriever;
    private _s3Retain;
    constructor(opts: IMessageOpts);
    parse(): Promise<string | any>;
    isHandled(): boolean;
    del(): Promise<void>;
    keep(): void;
    release(): Promise<void>;
    changeVisibility(timeoutInSeconds: number): Promise<void>;
    private _getBlobMessage;
}
export {};
